==> agentpy-0.1.3.tar.gz: agentpy-0.1.3/README.md <==
# AgentPy - Agent-based modeling in Python

[![PyPI](https://img.shields.io/pypi/v/agentpy)](https://pypi.org/project/agentpy/)
[![GitHub](https://img.shields.io/github/license/joelforamitti/agentpy)](https://github.com/JoelForamitti/agentpy/blob/master/LICENSE)
[![Build Status](https://travis-ci.com/JoelForamitti/agentpy.svg?branch=master)](https://travis-ci.com/JoelForamitti/agentpy)
[![Documentation Status](https://readthedocs.org/projects/agentpy/badge/?version=latest)](https://agentpy.readthedocs.io/en/latest/?badge=latest)
[![codecov](https://codecov.io/gh/JoelForamitti/agentpy/branch/master/graph/badge.svg?token=NTW99HNGB0)](https://codecov.io/gh/JoelForamitti/agentpy)
[![DOI](https://joss.theoj.org/papers/10.21105/joss.03065/status.svg)](https://doi.org/10.21105/joss.03065)

AgentPy is an open-source library for the development and analysis of agent-based models in Python. 
The framework integrates the tasks of model design, interactive simulations, numerical experiments, 
and data analysis within a single environment, and is optimized for interactive computing 
with [IPython](http://ipython.org/) and [Jupyter](https://jupyter.org/). 

Please cite this software as follows:

    Foramitti, J., (2021). AgentPy: A package for agent-based modeling in Python. 
    Journal of Open Source Software, 6(62), 3065, https://doi.org/10.21105/joss.03065

**Installation:** `pip install agentpy`

**Documentation:** https://agentpy.readthedocs.io

**Discussion forum:** https://github.com/JoelForamitti/agentpy/discussions

**Tutorials and examples:** https://agentpy.readthedocs.io/en/latest/model_library.html

**Comparison with other frameworks**: https://agentpy.readthedocs.io/en/latest/comparison.html

==> agentpy-0.1.4.tar.gz: agentpy-0.1.4/README.md <==
# AgentPy - Agent-based modeling in Python

[![PyPI](https://img.shields.io/pypi/v/agentpy)](https://pypi.org/project/agentpy/)
[![GitHub](https://img.shields.io/github/license/joelforamitti/agentpy)](https://github.com/JoelForamitti/agentpy/blob/master/LICENSE)
[![Build Status](https://travis-ci.com/JoelForamitti/agentpy.svg?branch=master)](https://travis-ci.com/JoelForamitti/agentpy)
[![Documentation Status](https://readthedocs.org/projects/agentpy/badge/?version=latest)](https://agentpy.readthedocs.io/en/latest/?badge=latest)
[![codecov](https://codecov.io/gh/JoelForamitti/agentpy/branch/master/graph/badge.svg?token=NTW99HNGB0)](https://codecov.io/gh/JoelForamitti/agentpy)
[![DOI](https://joss.theoj.org/papers/10.21105/joss.03065/status.svg)](https://doi.org/10.21105/joss.03065)

AgentPy is an open-source library for the development and analysis of agent-based models in Python. 
The framework integrates the tasks of model design, interactive simulations, numerical experiments, 
and data analysis within a single environment. The package is optimized for interactive computing 
with [IPython](http://ipython.org/), [IPySimulate](https://github.com/JoelForamitti/ipysimulate), and [Jupyter](https://jupyter.org/). 

Please cite this software as follows:

    Foramitti, J., (2021). AgentPy: A package for agent-based modeling in Python. 
    Journal of Open Source Software, 6(62), 3065, https://doi.org/10.21105/joss.03065

**Installation:** `pip install agentpy`

**Documentation:** https://agentpy.readthedocs.io

**JOSS publication:** https://doi.org/10.21105/joss.03065

**Discussion forum:** https://github.com/JoelForamitti/agentpy/discussions

**Tutorials and examples:** https://agentpy.readthedocs.io/en/latest/model_library.html

**Comparison with other frameworks**: https://agentpy.readthedocs.io/en/latest/comparison.html
